/*
 * Copyright (c) 1996 Palevich-Chen Industries, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for all purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies.
 *
 * PALEVICH-CHEN INDUSTRIES MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT
 * THE SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE
 * FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
 * OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

import java.awt.*;
import java.io.*;

class JJDictFrame extends Frame {
	JJDictFrame() {
	    super("JJDict Japanese-English Dictionary");
	    this.edict = edict;
	    setLayout(new BorderLayout());
	    add("North", input);
	    add("Center", output);

	    MenuBar menuBar = new MenuBar();
	    Menu file = new Menu("File");
	    aboutItem = new MenuItem("About...");
	    quit = new MenuItem("Quit");
	    file.add(aboutItem);
	    file.add("-");
	    file.add(quit);
	    menuBar.add(file);
	    setMenuBar(menuBar);

	    about();
    }

    public boolean action(Event event, Object object){
        output.appendText(event + " " + object);
        if ( event.target == input ){
            lookup();
        }
        else if ( event.target == aboutItem ) {
            about();
        }
        else if ( event.target == quit ) {
            System.exit(0);
        }
        else {
            return super.action(event, object);
        }
        return true;
    }

    void about(){
        output.setText(
            "jjdict Japanese-English Dictionary Program v1.0\n" +
            "\n"+
            "       by Jack Palevich, http://www.palevich.com\n" +
            "\n"+
            "       based on Jim Breen's EDICT file,\n"+
            "       http://www.rdt.monash.edu.au/~jwb/edict.html\n" +
            "\n" +
            "Type in an English or Japanese word or phrase into the text field above,\n" +
            "and then press Enter.  The Japanese phrase must be encoded in the EUC\n" +
            "character set encoding. (Sorry, no Shift-JIS or Unicode yet.)\n" +
            "\n" +
            "Most Java implementations do not fully support editing Japanese\n" +
            "text. So, for example, the arrow keys might not work correctly.\n" +
            "\n" +
            "If you don't have a Japanese font installed on your system,\n"+
            "you will be less than excited by the Japanese output. :-)\n" +
            "If you are running Windows 3.1 or Windows 95, you might try\n" +
            "the font and input system demo available from http://www.unionway.com\n"
            );
    }
    void lookup(){
        String key = input.getText();
        output.setText("Looking up " + key + "\n_____________\n");

        if ( edict == null ) {
            output.appendText("Loading dictionary -- please wait...\n_____________\n");
            try {
                edict = new EDict();
            }
            catch ( IOException e) {
                output.appendText("Could not load dictionary: " + e);
                return;
            }
        }
        EDictIterator iterator = edict.entriesAt(key);
        int count = 0;
        while ( iterator.hasMoreElements() ){
            String entry = (String) iterator.nextElement();
            output.appendText(entry + "\n");
            count++;
        }
        output.appendText("________________\n" + count + " entries found.\n");
    }
    private TextField input = new TextField();
    private TextArea output = new TextArea();
    private EDict edict;
    private MenuItem aboutItem;
    private MenuItem quit;
}
